==> eiffelstudio-18.07.10.1981.tar: F_code/C15/xm707.c <==
/*
 * Code for class XM_XPATH_TRACING_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm707.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_TRACING_ITERATOR}.make */
void F1570_13439 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg3;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XPATH_TRACING_ITERATOR}.item */
EIF_REFERENCE F1570_13440 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	RTCT0("precondition_not_off", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	Result = (EIF_REFERENCE) loc1;
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_ITERATOR}.after */
EIF_BOOLEAN F1570_13441 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10493[Dtype(tr1)-1559])(RTCW(tr1));
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_ITERATOR}.forth */
void F1570_13443 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,loc1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_) == ((EIF_INTEGER_32) 0L))) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R10506[Dtype(tr1)-1558])(RTCW(tr1));
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R10507[Dtype(tr1)-1559])(RTCW(tr1));
	}
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_))++;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O10488[Dtype(tr1)-1558]);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		F1559_13318(Current, loc2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10493[Dtype(tr1)-1559])(RTCW(tr1));
		if ((EIF_BOOLEAN) !tb1) {
			*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10486[Dtype(tr1)-1559])(RTCW(tr1));
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
			tr1 = RTOSCF(8222,F1128_8222,(Current));
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr3 = RTMS_EX_H(" [",2,8283);
			loc1 = F1113_8059(RTCW(tr1), tr2, tr3);
			tr1 = RTOSCF(8222,F1128_8222,(Current));
			ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_);
			tr2 = c_outi(ti4_1);
			loc1 = F1113_8069(RTCW(tr1), loc1, tr2);
			tr1 = RTOSCF(8222,F1128_8222,(Current));
			tr2 = RTMS_EX_H("]",1,93);
			loc1 = F1113_8069(RTCW(tr1), loc1, tr2);
			tr1 = F1570_13440(Current);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			F1180_9422(Current, loc1, tr1, tr2);
		} else {
			if (*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_)) {
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
				tr2 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
				F1180_9422(Current, tr1, NULL, tr2);
			}
		}
	}
	RTLE;
}

/* {XM_XPATH_TRACING_ITERATOR}.another */
EIF_REFERENCE F1570_13444 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,tr4);
	RTLR(5,Result);
	RTLIU(6);
	
	RTGC;
	tr1 = RTLNSMART(Dftype(Current));
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10513[Dtype(tr2)-1559])(RTCW(tr2));
	tr3 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	tr4 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	F1570_13439(RTCW(tr1), tr2, tr3, tr4);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_ITERATOR}.base_iterator */
EIF_REFERENCE F1570_13445 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XM_XPATH_TRACING_ITERATOR}.label */
EIF_REFERENCE F1570_13446 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {XM_XPATH_TRACING_ITERATOR}.context */
EIF_REFERENCE F1570_13447 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {XM_XPATH_TRACING_ITERATOR}.internal_item */
EIF_REFERENCE F1570_13448 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


void EIF_Minit707 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C15/xm707.c <==
/*
 * Code for class XM_XPATH_TRACING_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm707.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_TRACING_ITERATOR}.make */
void F1577_13502 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg3;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XPATH_TRACING_ITERATOR}.item */
EIF_REFERENCE F1577_13503 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	RTCT0("precondition_not_off", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	Result = (EIF_REFERENCE) loc1;
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_ITERATOR}.after */
EIF_BOOLEAN F1577_13504 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10548[Dtype(RTCW(tr1))-1568])(tr1);
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_ITERATOR}.forth */
void F1577_13506 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,loc1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_) == ((EIF_INTEGER_32) 0L))) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R10561[Dtype(RTCW(tr1))-1568])(tr1);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R10562[Dtype(RTCW(tr1))-1568])(tr1);
	}
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_))++;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O10543[Dtype(tr1)-1567]);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		F1568_13399(Current, loc2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10548[Dtype(RTCW(tr1))-1568])(tr1);
		if ((EIF_BOOLEAN) !tb1) {
			*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10541[Dtype(RTCW(tr1))-1568])(tr1);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
			tr1 = RTOSCF(8292,F1130_8292, (Current));
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr3 = RTMS_EX_H(" [",2,8283);
			loc1 = F1115_8129(RTCW(tr1), tr2, tr3);
			tr1 = RTOSCF(8292,F1130_8292, (Current));
			ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_);
			tr2 = c_outi(ti4_1);
			tr1 = F1115_8139(RTCW(tr1), loc1, tr2);
			loc1 = (EIF_REFERENCE) tr1;
			tr1 = RTOSCF(8292,F1130_8292, (Current));
			tr2 = RTMS_EX_H("]",1,93);
			tr1 = F1115_8139(RTCW(tr1), loc1, tr2);
			loc1 = (EIF_REFERENCE) tr1;
			tr1 = F1577_13503(Current);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			F1182_9492(Current, loc1, tr1, tr2);
		} else {
			if (*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_)) {
				F1182_9492(Current, *(EIF_REFERENCE *)(Current + _REFACS_3_), NULL, *(EIF_REFERENCE *)(Current + _REFACS_4_));
			}
		}
	}
	RTLE;
}

/* {XM_XPATH_TRACING_ITERATOR}.another */
EIF_REFERENCE F1577_13507 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	Result = RTLNSMART(Dftype(Current));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10568[Dtype(RTCW(tr1))-1568])(tr1);
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	tr3 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	F1577_13502(RTCW(Result), tr1, tr2, tr3);
	RTLE;
	return Result;
}

void EIF_Minit707 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
